==> flink-1.12.7-src.tgz: flink-1.12.7/flink-table/flink-table-api-java/src/main/java/org/apache/flink/table/operations/ExplainOperation.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.operations;

import java.util.Collections;

/**
 * Operation to describe an EXPLAIN statement. NOTES: currently, only default behavior(EXPLAIN PLAN
 * FOR xx) is supported.
 */
public class ExplainOperation implements Operation {
    private final Operation child;

    public ExplainOperation(Operation child) {
        this.child = child;
    }

    public Operation getChild() {
        return child;
    }

    @Override
    public String asSummaryString() {
        return OperationUtils.formatWithChildren(
                "EXPLAIN PLAN FOR",
                Collections.emptyMap(),
                Collections.singletonList(child),
                Operation::asSummaryString);
    }
}

==> flink-1.13.5-src.tgz: flink-1.13.5/flink-table/flink-table-api-java/src/main/java/org/apache/flink/table/operations/ExplainOperation.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.operations;

import java.util.Collections;

/**
 * Operation to describe an EXPLAIN statement. NOTES: currently, only default behavior (EXPLAIN
 * [PLAN FOR] xx) is supported.
 */
public class ExplainOperation implements Operation {
    private final Operation child;

    public ExplainOperation(Operation child) {
        this.child = child;
    }

    public Operation getChild() {
        return child;
    }

    @Override
    public String asSummaryString() {
        return OperationUtils.formatWithChildren(
                "EXPLAIN",
                Collections.emptyMap(),
                Collections.singletonList(child),
                Operation::asSummaryString);
    }
}
